@@ -241,9 +241,6 @@ class Job:
         }
         if self.type != JobType.BATCH:
             job_dict["entrypoint"] = str(self.entrypoint) if self.entrypoint else None
-            job_dict["image"] = (self.image,)
-            job_dict["memory"] = (self.resources.memory,)
-            job_dict["cpu"] = self.resources.cpu
         return job_dict
 
     def from_dict(self, job_dict: dict):
