@@ -21,14 +21,14 @@ logger = DatatailrLogger(os.path.abspath(__file__)).get_logger()
 def run():
     logger.info("Starting Datatailr excel add-in...")
     entrypoint = os.environ.get("DATATAILR_ENTRYPOINT")
-    hostname = os.environ.get("DATATAILR_HOST")
+    # hostname = os.environ.get("DATATAILR_HOST")
 
     if entrypoint is None:
         raise ValueError("Environment variable 'DATATAILR_ENTRYPOINT' is not set.")
 
-    if hostname is None:
-        raise ValueError("Environment variable 'DATATAILR_HOST' is not set.")
+    # if hostname is None:
+    #     raise ValueError("Environment variable 'DATATAILR_HOST' is not set.")
 
-    entrypoint = f'./dt-excel.sh -n -H "{hostname}" -p 8080 "{entrypoint}"'
+    # entrypoint = f'./dt-excel.sh -n -H "{hostname}" -p 8080 "{entrypoint}"'
     logger.info(f"Running entrypoint: {entrypoint}")
     subprocess.run(entrypoint, shell=True)
